@@ -1,9 +1,7 @@
 # -*- coding:utf-8 -*-
-# Copyright 1999-2019 Gentoo Authors
+# Copyright 1999-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import print_function, unicode_literals
-
 import errno
 import io
 import logging
@@ -41,7 +39,7 @@ from repoman import VERSION
 bad = create_color_func("BAD")
 
 
-class Actions(object):
+class Actions:
 	'''Handles post check result output and performs
 	the various vcs activities for committing the results'''
 
